==> haskell-chunked-data-0.2.0-7-armv7h.pkg.tar.xz: usr/share/haskell/haskell-chunked-data/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: chunked-data
version: 0.2.0
id: chunked-data-0.2.0-dc8f031d60c38d417f6a1c9018e0503e
key: chunk_INb7Co3QUK9KXJZdynQ9aO
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/fpco/chunked-data
synopsis: Typeclasses for dealing with various chunked data representations
description:
    Originally present in classy-prelude.
category: Data
author: Michael Snoyman
exposed: True
exposed-modules:
    Data.IOData Data.Textual.Encoding Data.Sequences.Lazy Data.Builder
    Data.ChunkedZip
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/chunked-data-0.2.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/chunked-data-0.2.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/chunked-data-0.2.0
hs-libraries: HSchunked-data-0.2.0-INb7Co3QUK9KXJZdynQ9aO
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-adef087994cafeb1970772b79d5f710a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    mono-traversable-0.10.1-a53fee0fd8cdcdc2da55eaf19944a735
    semigroups-0.18.0.1-09717ed0a84e1dbeffebbb54d604d271
    text-1.2.1.3-6c3c87c392cdf2c29fca1c10bbf7250b
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    vector-0.11.0.0-c9b9eff80d809aeb097685ce86af03c4
haddock-interfaces: /usr/share/doc/haskell-chunked-data/html/chunked-data.haddock
haddock-html: /usr/share/doc/haskell-chunked-data/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-chunked-data-0.2.0-8-armv7h.pkg.tar.xz: usr/share/haskell/haskell-chunked-data/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: chunked-data
version: 0.2.0
id: chunked-data-0.2.0-d6d31e5927728350964419b731816e7b
key: chunk_5FMfTe2tG56KlokOcQAhrl
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/fpco/chunked-data
synopsis: Typeclasses for dealing with various chunked data representations
description:
    Originally present in classy-prelude.
category: Data
author: Michael Snoyman
exposed: True
exposed-modules:
    Data.IOData Data.Textual.Encoding Data.Sequences.Lazy Data.Builder
    Data.ChunkedZip
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/chunked-data-0.2.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/chunked-data-0.2.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/chunked-data-0.2.0
hs-libraries: HSchunked-data-0.2.0-5FMfTe2tG56KlokOcQAhrl
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    mono-traversable-0.10.1-6e9fa89edc8b9472b6cad8340678b5ca
    semigroups-0.18.0.1-8982ad8edd41304214263f489c2b00c2
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-chunked-data/html/chunked-data.haddock
haddock-html: /usr/share/doc/haskell-chunked-data/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
